@@ -4,6 +4,7 @@
 #'
 #' @param tableau A list containing the Tableau authentication variables: `base_url` and `token`.
 #' @param api_version The API version to use (default: 3.4).
+#' @param page_number The page number of the results to retrieve (default: 1).
 #' @param page_size The number of records to retrieve per page (default: 100).
 #' @param include_metadata Logical indicating whether to include metadata columns in the result (default: FALSE).
 #'
@@ -11,7 +12,7 @@
 #' @export
 #'
 #' @family Tableau REST API
-get_server_schedules <- function(tableau, api_version = 3.4, page_size = 100, include_metadata = FALSE) {
+get_server_schedules <- function(tableau, api_version = 3.4, page_number = 1, page_size = 100, include_metadata = FALSE) {
   base_url <- tableau$base_url
   token <- tableau$token
 
@@ -20,7 +21,9 @@ get_server_schedules <- function(tableau, api_version = 3.4, page_size = 100, in
     "api/",
     api_version,
     "/schedules?fields=_all_&pageSize=",
-    page_size
+    page_size,
+    "&pageNumber=",
+    page_number
   )
 
   api_response <- httr::GET(
